
Proximiant Mobile SDK
=====================
The Proximiant app lets consumers instantly beam receipts to their phones wherever they shop! Just tap their smartphone on the store's scanner, or snap a picture of the receipt with their phone's camera. Staying organized has never been this easy!

With the **Proximaint Mobile SDK**, other apps can easily benefit from digital receipts capability developed by Proximiant. To illustrate the main functionality of our mobile SDK, we also included a reference app. We currently provide an Android version of the SDK, and the iOS version is coming soon. 

For detailed documentation of our SDK, please refer to [http://dev.proximiant.com/docs/mobile-sdk].

----------
Main functionality of the reference app
---------

#### <i class="icon-file"></i> Touch & Go receipt collection
Touch a NFC enabled phone with the reference app over **Proximiant transceiver** or compatible payment terminals to beam the receipt directly onto the phone.

#### <i class="icon-file"></i> Scan & Go receipt collection
Scan the QR code displayed on the **Proximiant transceiver** or compatible payment terminal to collect the receipt.

#### <i class="icon-file"></i> Receipt repository
List view of all receipts that a shopper has collected.

#### <i class="icon-file"></i> Receipt Search
Search the receipt repository by store or product keywords

#### <i class="icon-file"></i> Receipt Detail view
In the detail view, the receipt is itemized, and  with targeted marketing and CRM content based on what product shopper buys. Shoppers can
click-to-share the products they purchase directly from the product lines in the receipt.


----------
## Mobile SDK components
We describe major components of Proximiant mobile SDK, and illustrate their usage here.

### How to enable NFC reader?
To enable your mobile app to have the **Touch & Go** capability, follow the following steps:

* Import <i> proximiant_nfc_lib.jar</i> to your project.
* Create a new Activity to handle NFC.
* Update <i>AndroidManifest.xml</i> to include the NFC Activity as shown below.
```XML
<uses-permission android:name="android.permission.NFC" />
<uses-permission android:name="android.permission.INTERNET" />
......
<intent-filter>
	<action   android:name="android.nfc.action.NDEF_DISCOVERED" />
	<data android:mimeType="application/proximiant" />
	<category android:name="android.intent.category.DEFAULT"/>
</intent-filter>
```
   > Note that the data filter field has to use above pattern to have NFC auto trigger the mobile app.

* Update your <i>Activity.java</i> that needs to hook up with NFC notification:
   * Make your <i>Activity.java</i> implement Observer
   * import the proximiant lib class:
```Java
import proximiant.sdk.ProximiantNfcMessage;
import proximiant.sdk.ProximiantNFCReader;
```

   * Create an <i>ProximiantNFCReader</i> instance 

```	
private ProximiantNFCReader _myNfcReader = null; `
```
   * In <i>onCreate()</i>, add the following code fragment: 
```Java
_myNfcReader = new ProximiantNFCReader(this);
_myNfcReader.addObserver(this);
```

   * In <i>onResume()</i>,  add: 
```Java
if (_myNfcReader != null) { _myNfcReader.enableDetection(); } 
```

   * In <i>onPause()</i>, add the code fragment below: 
```Java
@Override
protected void onPause() {
	super.onPause();
	if (_myNfcReader != null) {
		_myNfcReader.disableForeground();
	}
}
```

   * Hook up <i>Observer</i>:
```Java
public void update(Observable observable, Object data) {
	if (data instanceof ProximiantNfcMessage) {
		...
	} 
}
```

### How to enable **Scan & Go** feature?
*  In your Activity that handles QR Scanning, add following import statement:

```   
import proximiant.sdk.qrcode.QRCodeScanner;
```

*  Update <i>AndroidManifest.xml</i> for the NFC Activity as follows:
```XML
<uses-permission android:name="android.permission.CAMERA" />
<uses-permission android:name="android.permission.INTERNET" />
<uses-permission android:name="android.permission.ACCESS_WIFI_STATE"/>
...
```

*  Make your activity extend QRCodeScanner.
```Java
public class MyQRCodeActivity extends QRCodeScanner {
...
```

*  In your <i>layout.xml</i>, for this Activity, define a FrameLayout as the container for preview.
```XML
<FrameLayout android:id="@+id/preview"
	android:layout_weight="1" android:layout_width="fill_parent"
	android:layout_height="fill_parent"
	/>
```

*  Update Your activity <i>onCreate</i> to create a preview area for Scanning.
```XML
	setCameraPreview(((FrameLayout) findViewById(R.id.preview)));
```

*  Override onQRCodeResult to get QR result, code is a json string of the result.
```Java
public void onQRCodeResult(Boolean success, String code) {
	Log.d(TAG, "QR Result is " + code);
	...
}
```

### Use our Client API to communicate with Proximiant server backend
* import following class to your class:
```Java
import proximiant.sdk.api.ProximiantApiResult;
import proximiant.sdk.api.ProximiantClientApi;
```

* Declare a client instance:
```Java
private final ProximiantClientApi client = new ProximiantClientApi(ProximiantClientApi.STAGE);
```

* Initialize the client: (Make sure your server side implement acquire access token from our server.)
```Java
client.addObserver(this);
client.setAccessCode(accessToken); 
	// required, need to get this token from your own server.
client.setCacheExpire(this, 30); 
	// if you need our client to take care of local cache.
```

*  Override the <i>update</i> method

```Java
@Override
public void update(Observable observable, Object data) {
	Log.d(TAG, "Gettting data!!" + data.toString());
	if (data.getClass() == ProximiantApiResult.class) {
		ProximiantApiResult r = (ProximiantApiResult) data;
		_tv.setText(r.getJsonString());
	}
}
```


--------

#### <i class="icon-download"></i>Download the SDK and introduce digital receipts into your mobile applications.
