//
//  ProxCameraViewController.m
//  proxRefApp
//
//  Created by rui yang on 9/25/13.
//  Copyright (c) 2013 rui yang. All rights reserved.
//

#import "ProxCameraViewController.h"
#import "qrcode.h"


@interface ProxCameraViewController ()
@property (nonatomic, strong) QrCode * qr;
@property (nonatomic, strong) PROXCALLBACK block;
@property (nonatomic, strong) UIView * previewContainer;
@property (nonatomic, strong) UIButton * cancelButton;
@property (nonatomic, strong) UIButton * okButton;
@property (nonatomic, strong) UIButton * scanButton;
@property (nonatomic, strong) UIButton * resetButton;
@property (nonatomic, strong) UIScrollView * thumbs;
@property (nonatomic) int thumb_x;
@end

@implementation ProxCameraViewController

- (void) toggleOkButton:(BOOL) ok {
  NSLog(@"enable ok button");
  self.okButton.enabled = ok;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    // TODO: use story board for iphone/ipad so we do not need to reset calculate position.
  
    // Do any additional setup after loading the view.
  ProxCameraViewController * __weak weakSelf = self;
  
  self.thumb_x = 0;
  
  APICALLBACK apiCallback = ^(NSString* t, NSString* v, NSDictionary * json) {
    NSLog(@"result is %@", v);
    self.myApiCallBack(t,v, json);
    [self dismissViewControllerAnimated:YES completion:nil];
  };
  
  self.block = ^(UIImage* img, CAMERA_TYPE t, NSString* v) {
    NSLog(@"type is: %d -- %@", t, v);
    if (t == SCAN) {
      [weakSelf.client registerReceipt:v done:apiCallback];
      [weakSelf dismissViewControllerAnimated:YES completion:nil];
      return;
    }
    if (t == TAKE) {
      UIImageView * imgV = [[UIImageView alloc] initWithFrame:CGRectMake(weakSelf.thumb_x, 5, 50, 100)];
      weakSelf.thumb_x += 60;
      imgV.image = img;
      [weakSelf.thumbs addSubview:imgV];
      [weakSelf.thumbs setContentSize:CGSizeMake(weakSelf.thumb_x, 100)];
      [weakSelf toggleOkButton:YES];
      return;
    }
    if (t == DONETAKE) {
      NSLog(@"finishing the photo receipt.");
      [weakSelf.client cameraReceipt:img total:0 subTotal:0 description:@"" done:apiCallback];
    }
    
  };
  self.qr = [[QrCode alloc] init];
  self.previewContainer = [[UIView alloc] initWithFrame:CGRectMake(0, 0, 320, 320)];
  [self.qr setup:self.previewContainer done:self.block];
  [self.view addSubview:self.previewContainer];
  [self.qr scan];
  [self.view setBackgroundColor:[UIColor whiteColor]];
  
  self.cancelButton = [UIButton buttonWithType:UIButtonTypeRoundedRect];
  self.okButton = [UIButton buttonWithType:UIButtonTypeRoundedRect];
  self.scanButton = [UIButton buttonWithType:UIButtonTypeRoundedRect];
  self.resetButton = [UIButton buttonWithType:UIButtonTypeRoundedRect];
  self.thumbs = [[UIScrollView alloc] initWithFrame:CGRectMake(0, 350, 320, 100)];
  
  self.cancelButton.frame = CGRectMake(10, 325, 70, 20);
  self.okButton.frame = CGRectMake(85, 325, 70, 20);
  self.scanButton.frame = CGRectMake(160, 325, 70, 20);
  self.resetButton.frame = CGRectMake(235, 325, 70, 20);
  
  [self.cancelButton setTitle:@"Cancel" forState:UIControlStateNormal];
  [self.okButton setTitle:@"Ok" forState:UIControlStateNormal];
  [self.scanButton setTitle:@"Take" forState:UIControlStateNormal];
  [self.resetButton setTitle:@"Reset" forState:UIControlStateNormal];
  
  [self.cancelButton addTarget:self action:@selector(buttonTapped:) forControlEvents: UIControlEventTouchUpInside];
  [self.okButton addTarget:self action:@selector(buttonTapped:) forControlEvents: UIControlEventTouchUpInside];
  [self.scanButton addTarget:self action:@selector(buttonTapped:) forControlEvents: UIControlEventTouchUpInside];
  [self.resetButton addTarget:self action:@selector(buttonTapped:) forControlEvents: UIControlEventTouchUpInside];
  
  [self.view addSubview:self.cancelButton];
  [self.view addSubview:self.okButton];
  [self.view addSubview:self.scanButton];
  [self.view addSubview:self.resetButton];
  [self.view addSubview:self.thumbs];
  [self toggleOkButton:NO];

}

- (IBAction)buttonTapped:(UIButton *)button {
  if ([button isEqual:self.cancelButton]) {
    [self dismissViewControllerAnimated:YES completion:nil];
  } else if ([button isEqual:self.okButton]) {
    [self.qr donePhoto];
    [self dismissViewControllerAnimated:YES completion:nil];
  } else if ([button isEqual:self.scanButton]) {
    if ([button.titleLabel.text isEqualToString:@"Take"]) {
      [button setTitle:@"New" forState:UIControlStateNormal];
      [self.qr take];
    } else if ([button.titleLabel.text isEqualToString:@"New"]) {
      [button setTitle:@"Take" forState:UIControlStateNormal];
      [self.qr scan];
    }
  } else if ([button isEqual:self.resetButton]) {
    [self.qr reset];
    self.thumb_x = 0;
    [self toggleOkButton:NO];
    [[self.thumbs subviews] makeObjectsPerformSelector:@selector(removeFromSuperview)];
  }
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
