//
//  ProximiantClientApi.h
//  client_api_lib
//
//  Created by rui yang on 7/30/13.
//  Copyright (c) 2013 rui yang. All rights reserved.
//

#import <Foundation/Foundation.h>

#define RECEIPT_FAILURE @"receipt_failure"
#define RECEIPT_LIST @"receipt_list"
#define RECEIPT_DETAIL @"receipt_detail"
#define REG_RECEIPT @"register"
#define ADS @"ad"
#define NOTIFICATION @"notification"
#define  PROX_ACCESS_TOKEN  @"proxAccessToken"
#define USER_PROFILE @"get_user_profile"
#define API_ERROR @"proxApiError"
#define CAMERA_RECEIPT @"create_picture_receipt"
#define GET_CAMERA_RECEIPT @"get_picture_receipt"
#define STORES @"business/stores/"
#define LOYALTY @"loyaltyprogram/"
#define USER_LOYALTY_CARD @"loyaltycards/"
#define SUGGESTED_LOYALTY_CARD @"suggested_loyaltycards/"
#define CREATE_USER_LOYALTY_CARD @"create_user_loyalty_card"
#define DELETE_USER_LOYALTY_CARD @"delete_user_loyalty_card"
#define GROUP @"groups/"
#define CREATE_GROUP @"create_group"
#define UPDATE_GROUP @"update_group"
#define DELETE_GROUP @"del_groups/"
#define ADD_RECEIPT_GROUP @"add_receipt_to_group"
#define DEL_RECEIPT_FROM_GROUP @"del_receipt_from_group"
#define CHAT @"chat/"
#define CREATE_CHAT @"add_comments/"
#define RECEIPT_HTML @"html"

typedef enum {
  PROD, STAGE, DEV
} ENV_TYPE;

typedef enum {
  QUESTION, ANSWER
} MESSAGE_TYPE;

typedef void (^APICALLBACK)(NSString*, NSString*, NSDictionary *);
typedef void (^IMAGE_CALLBACK)(NSString*, UIImage *, NSError*);

@interface ProximiantClientApi : NSObject
- (void) clearReceiptsCache: (int) page;
- (void) getAds: (NSString*) rid done:(APICALLBACK)block;
- (NSString*) getApiHost;
- (void) getReceiptByRid: (NSString*) rid done:(APICALLBACK)block;
- (void) getReceipts: (int) page done:(APICALLBACK)block;
- (void) registerReceipt: (NSString*) rid done:(APICALLBACK)block;
- (void) cameraReceipt: (UIImage*) image total:(int) t subTotal:(int) st description:(NSString*) text done:(APICALLBACK)block;
- (void) searchReceipts: (NSString*) query page:(int) page done:(APICALLBACK)block;
- (void) setAccessCode: (NSString*) accessCode;
- (void) setCacheExpire: (int) expireInSeconds;
- (NSString*) decodeB64String: (NSString*) b64String;
- (NSString*) b64EncodeString: (NSString*) text;

- (NSData*) decodeB64Data: (NSString*) b64String;
- (NSString*) b64EncodeData: (NSData*) data;

- (NSString*) b64EncodeImage: (UIImage*) image;

- (UIImage *)generatePhotoThumbnail:(UIImage *)image;

- (void) getUserProfile:(APICALLBACK)block;

- (void) getStores:(APICALLBACK)block;
- (void) getCameraReceiptImage:(NSString*) rid done:(IMAGE_CALLBACK)block;
- (void) getReceiptHtml:(NSString*) rid done:(APICALLBACK) block;

- (void) getLoyaltyProgram:(int) programId done:(APICALLBACK)block;
- (void) getLoyaltyPrograms:(APICALLBACK)block;

- (void) getSuggestedLoyaltyCards:(APICALLBACK)block;
- (void) getUserLoyaltyCards:(APICALLBACK)block;
- (void) delUserLoyaltyCard:(NSString*) idUserLoyaltyCard done:(APICALLBACK)block;
- (void) createUserLoyaltyCard:(NSString *) businessName businessId:(NSString*)bId barcode:(NSString*) barcode barcodeType:(NSString*) barcodeType done:(APICALLBACK)block;

- (void) checkProxAuth:(NSString*) cId clientSecret:(NSString*) secret done:(APICALLBACK)block;

- (void) getAccessTokenByRefreshToken: (NSString*) refreshToken clientId:(NSString*) cId clientSecret:(NSString*) secret done:(APICALLBACK)block;

- (void) getUserProjects:(APICALLBACK)block;
- (void) getUserProjectDetail:(int) idUserProject done:(APICALLBACK)block;
- (void) createUserProject:(NSString*) name color:(NSString*)colorCode description:(NSString*) desc done:(APICALLBACK)block;
- (void) updateUserProject:(int) idUserProject name:(NSString*) name color:(NSString*) colorCode description:(NSString*) desc done:(APICALLBACK)block;
- (void) deleteUserProject:(int) idUserProject done:(APICALLBACK)block;
- (void) addReceiptToUserProject:(int) idUserProject rid:(NSString*)rid done:(APICALLBACK)block;
- (void) deleteReceiptFromUserProject:(int) idUserProject rid:(NSString*)rid done:(APICALLBACK)block;

- (void) getChatHistoryForFranchise:(int) idFranchise done:(APICALLBACK)block;
- (void) getChatHistoryForStore:(int) idStore done:(APICALLBACK)block;
- (void) getChatHistoryForProduct:(int) idProduct done:(APICALLBACK)block;
- (void) getChatHistoryForReceipt:(NSString*) rid done:(APICALLBACK)block;
- (void) addNewTextChat:(int) idPost text:(NSString*) text type:(MESSAGE_TYPE)type done:(APICALLBACK) block;
- (void) addNewImageChat:(int) idPost image:(UIImage *)image type:(MESSAGE_TYPE)type done:(APICALLBACK) block;



- (void) getAccessTokenByFacebookToken: (NSString*) fbToken clientId:(NSString*) cId done:(APICALLBACK)block;

- (id) initWithEnv: (ENV_TYPE) env;

@end
